#
# spec file for package amazon-ssm-agent
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           amazon-ssm-agent
Version:        2.3.415.0
Release:        22.3
Summary:        Amazon Remote System Config Management
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/aws/amazon-ssm-agent
Source0:        %{name}-%{version}.tar.gz
Source1:        %{name}.service
Patch1:         fix-config.patch
Patch2:         fix-version.patch
BuildRequires:  go >= 1.7.4
BuildRequires:  systemd
Requires:       systemd
ExcludeArch:    s390

%description
This package provides the Amazon SSM Agent for managing EC2 Instances using
Amazon EC2 Systems Manager (SSM).

The SSM Agent runs on EC2 or on-premise instances and enables you to quickly
and easily execute remote commands or scripts against one or more instances.
When you execute a command, the agent on the instance processes the document
and configures the instance as specified.

This collection of capabilities helps you automate management tasks such as
collecting system inventory, applying operating system (OS) patches, automating
the creation of Amazon Machine Images (AMIs), and configuring operating systems
(OSs) and applications at scale. Systems Manager works with managed instances:
Amazon EC2 instances, or servers and virtual machines (VMs) in your on-premises
environment that are configured for Systems Manager.

%prep
%setup -q
%patch1 -p1
%patch2 -p1

%build
rm -rf vendor/src/github.com/aws/aws-sdk-go/vendor/

mkdir -p src/github.com/aws/amazon-ssm-agent
mv Tools agent vendor makefile amazon-ssm-agent.json.template \
seelog_unix.xml packaging src/github.com/aws/amazon-ssm-agent/

PKG_ROOT=`pwd`/src/github.com/aws/amazon-ssm-agent
GOPATH=${PKG_ROOT}/vendor:`pwd`
export GOPATH

go build -ldflags "-s -w" -o bin/amazon-ssm-agent -v \
${PKG_ROOT}/agent/agent.go \
${PKG_ROOT}/agent/agent_unix.go \
${PKG_ROOT}/agent/agent_parser.go

go build -ldflags "-s -w" -o bin/ssm-cli -v \
${PKG_ROOT}/agent/cli-main/cli-main.go

go build -ldflags "-s -w" -o bin/ssm-document-worker -v \
${PKG_ROOT}/agent/framework/processor/executer/outofproc/worker/main.go

go build -ldflags "-s -w" -o bin/ssm-session-worker -v \
${PKG_ROOT}/agent/framework/processor/executer/outofproc/sessionworker/main.go

go build -ldflags "-s -w" -o bin/ssm-session-logger -v \
${PKG_ROOT}/agent/session/logging/main.go

%install
install -d -m 755 %{buildroot}%{_sbindir}
install -d -m 755 %{buildroot}%{_bindir}
install -d -m 755 %{buildroot}%{_sysconfdir}/init
install -d -m 755 %{buildroot}%{_sysconfdir}/amazon/ssm
install -m 755 bin/amazon-ssm-agent %{buildroot}%{_sbindir}
install -m 755 bin/ssm-cli %{buildroot}%{_bindir}
install -m 755 bin/ssm-document-worker %{buildroot}%{_bindir}
install -m 755 bin/ssm-session-worker %{buildroot}%{_bindir}
install -m 755 bin/ssm-session-logger %{buildroot}%{_bindir}

mkdir -p %{buildroot}%{_unitdir}
install -m 755 %SOURCE1 %{buildroot}%{_unitdir}

PKG_ROOT=`pwd`/src/github.com/aws/amazon-ssm-agent
cp ${PKG_ROOT}/seelog_unix.xml %{buildroot}%{_sysconfdir}/amazon/ssm/seelog.xml.template
cp ${PKG_ROOT}/amazon-ssm-agent.json.template %{buildroot}%{_sysconfdir}/amazon/ssm/
cp ${PKG_ROOT}/packaging/linux/amazon-ssm-agent.conf %{buildroot}%{_sysconfdir}/init/

%files
%defattr(-,root,root,-)
%dir %{_sysconfdir}/init
%dir %{_sysconfdir}/amazon
%dir %{_sysconfdir}/amazon/ssm
%license LICENSE
%doc CONTRIBUTING.md NOTICE.md README.md
%config(noreplace) %{_sysconfdir}/init/amazon-ssm-agent.conf
%config(noreplace) %{_sysconfdir}/amazon/ssm/amazon-ssm-agent.json.template
%config(noreplace) %{_sysconfdir}/amazon/ssm/seelog.xml.template
%{_sbindir}/*
%{_bindir}/*
%{_unitdir}/%{name}.service

%pre
%service_add_pre %{name}.service

%preun
%service_del_preun %{name}.service

%post
%service_add_post %{name}.service

%postun
%service_del_postun %{name}.service

%changelog
* Wed Mar  6 2019 Sean Marlow <sean.marlow@suse.com>
- Update version patch.
- Update to 2.3.415.0 (2019-03-05)
  + Bug fix addressing issues in Distributor package upgrade
- Update to 2.3.372.0 (2019-03-05)
  + Bug fix to allow installation of Distributor packages that do
    not have a version name.
  + Bug fix for agent crash with message "WaitGroup is reused
    before previous Wait has returned".
- Update to 2.3.344.0 (2019-03-05)
  + Add frequent collector to detect changed inventory types and
    upload it to SSM service between two scheduled collections.
  + Change AWS Systems Manager Distributor to reduce calls to
    GetDocument by calling DescribeDocument.
  + Add exit code when ssm-cli execution fails.
  + Create ssm-user only after the control channel has been
    successfully created.
- Update to 2.3.274.0 (2019-03-05)
  + Enabled AWS Systems Manager Distributor that lets you securely
    distribute and install software packages.
  + Add support for the arm64 architecture on Amazon Linux 2,
    Ubuntu 16.04/18.04, and RHEL 7.6 to support EC2 A1 instances.
- Update to 2.3.235.0 (2019-03-05)
  + Bug fix for session manager logging on Windows
  + Bug fix for ConfigureCloudWatch plugin
  + Bug fix for update SSM agent occasionally failing due to SSM
    agent service stuck in starting state
- Update to 2.3.193.0 (2019-03-05)
  + Bug fix for past sessions occasionally stuck in terminating
    state
  + Darwin masquerades as Linux to bypass OS validation on the
    backend until official support can be added
- Update to 2.3.169.0 (2019-03-05)
  + Update managed instance role token more frequently
- Update to 2.3.136.0 (2019-03-05)
  + Bug fix for issue that GatherInventory throw out error when
    there is no Windows Update in instance
  + Add more filters when getting the Windows event logs at
    startup to improve performance
  + Add random jitter before call PutInventory in inventory
    datauploader
- Update to 2.3.117.0 (2019-03-05)
  + Bug fix for issues during process termination on instances
    where IAM policy does not grant ssmmessages permissions.
- Update to 2.3.101.0 (2019-03-05)
  + Bug fix to prevent defunct processes when creating the local
    user ssm-user.
  + Bug fix for sudoersFile permission to avoid "sudo" command
    warnings in Session Manager.
  + Disable hibernation on Windows platform if Cloudwatch
    configuration is present.
- Update to 2.3.68.0 (2019-03-05)
  + Enables the Session Manager capability that lets you manage
    your Amazon EC2 instance through an interactive one-click
    browser-based shell or through the AWS CLI.
  + Beginning this agent version, SSM Agent will create a local
    user "ssm-user" and either add it to /etc/sudoers (Linux) or
    to the Administrators group (Windows) every time the agent
    starts. The ssm-user is the default OS user when a Session
    Manager session is started, and the password for this user is
    reset on every session. You can change the permissions by
    moving the ssm-user to a less-privileged group or by changing
    the sudoers file. The ssm-user is not removed from the system
    when SSM Agent is uninstalled.
- Update to 2.3.13.0 (2019-03-05)
  + Bug fix for the SSM Agent service remaining in "Starting"
    state on Windows when unable to authenticate to the Systems
    Manager service.
- Update to 2.2.916.0 (2019-03-05)
  + Bug fix for missing cloudwatch.exe seen in SSM Agent version
    2.2.902.0
- Update to 2.2.902.0 (2019-03-05)
  + Initial support for developer builds on macOS
  + Retry sending Run Command execution results for up to 2 hours
  + More detailed error messages are returned for inventory plugin
    failures during State Manager association executions
- Update to 2.2.800.0 (2019-03-05)
  + Bug fix to clean the orchestration directory
  + Streaming AWS Systems Manager Run Command output to CloudWatch
    Logs
  + Reducing number of retries for serial port opening
  + Add retry logic to installation verification
- Update to 2.2.619.0 (2019-03-05)
  + Various bug fixes
- Update to 2.2.607.0 (2019-03-05)
  + Various bug fixes
- Update to 2.2.546.0 (2019-03-05)
  + Bug fix to retry sending document results if they couldn't
    reach the service
- Update to 2.2.493.0 (2019-03-05)
  + Added support for Ubuntu Snap packaging
  + Bug fix so that aws:downloadContent does not change permissions
    of directories
  + Bug fix to Cloudwatch plugin where StartType has duplicated
    Enabled value
- Update to 2.2.392.0 (2019-03-05)
  + Added support for agent hibernation so that Agent backs off or
    enters hibernation mode if it does not have access to the
    service
  + Various bug fixes
- Update to 2.2.355.0 (2019-03-05)
  + Fix S3Download to download from cross regions.
  + Various bug fixes
* Wed Mar 14 2018 sean.marlow@suse.com
- Update to 2.2.325.0 2018-03-07 (bsc#1085670)
  + Bug fix to change sourceHashType to be default sha256 on
    psmodule.
- Update to 2.2.257.0 2018-02-23
  + Bug fix to address an issue that can prevent the agent from
    processing associations after a restart.
- Update to 2.2.160.0 2018-01-15
  + Execute "pwsh" on linux when using runPowershellScript plugin.
- Update to 2.2.93.0 2017-11-14
  + Update to latest AWS SDK.
- Update to 2.2.58.0 2017-10-23
  + Switching to use Birdwatcher distribution service for AWS
    packages.
* Thu Feb  1 2018 ro@suse.de
- do not build on s390, only on s390x (no go on s390)
* Mon Nov 27 2017 sean.marlow@suse.com
- Update Go version requirement to 1.7.4.
* Wed Nov  8 2017 sean.marlow@suse.com
- Add ssm-document-worker binary to agent package.
* Wed Nov  8 2017 sean.marlow@suse.com
- Update to 2.2.45.0 2017-10-18 (bsc#1067256)
  + Refresh version patch with new version.
  + Adding versioning support for Parameter Store.
  + Added additional gatherers for inventory, including windows
    service gatherer, windows registry gatherer, file metadata
    gatherer, windows role gatherer.
  + Added support for aws:downloadContent plugin to download
    content from GitHub, S3 and documents from SSM documents.
  + Added support for aws:runDocument plugin to execute SSM
    documents.
- Update to 2.2.30.0 2017-10-09
  + Improved speed of initial association application on boot
  + Various aws:configurePackage service integration changes
  + Improved home directory detection in non-x64 linux platforms
    to address cases where shared AWS SDK credentials were not
    available in on-prem instances
- Update to 2.2.24.0 2017-10-02
  + Added exponential backoff in bucket region check for s3 upload
  + Fixed an issue with orchestration directory cleanup for
    RunCommand
- Update to 2.2.16.0 2017-09-25
- Update to 2.1.4.0 2017-09-11
  + Support for command execution out-of-process
- Update to 2.0.952.0 2017-08-28
* Fri Aug 25 2017 sean.marlow@suse.com
- Add ssm-cli to package.
- Remove requirement on lsb-release. Agent now parses os-release
  by default.
- Use gzip archive from GitHub instead of converting to xz.
- Update to 2.0.922.0 2017-08-14 (bsc#1055766)
  + Added Raspbian support for armv6 to support Raspberry Pi
  + Various bug fixes
- Update to 2.0.913.0 2017-08-07
  + Updated golang/sys dependency to the latest
  + Increased run command document maximum execution timeout to 48 hours
  + Various bug fixes
- Update to 2.0.902.0 2017-07-31
  + Added support for uploading agent logs to CloudWatch for SSM Agent diagnostics
  + Added additional gatherers for inventory
  + Added configuration compliance support for association
  + Various bug fixes
- Update to 2.0.879.0 2017-07-26
  + Add capability to configure custom s3 endpoint for the agent
  + Various bug fixes
- Update to 2.0.847.0 2017-07-03
  + Various bug fixes
- Update to 2.0.842.0 2017-06-26
  + Added rollback support in aws:configurePackage
  + Various bug fixes
- Update to 2.0.834.0 2017-06-23
  + Various bug fixes
- Update to 2.0.805.0 2017-06-07
  + Added support for SLES (SUSE) (64-bit, v12 and above)
  + Various bug fixes
- Update to 2.0.796.0 2017-05-29
  + Linux platform version now based on os-release when available
  + Various bug fixes
* Wed May 31 2017 sean.marlow@suse.com
- Update to 2.0.790.0 2017-05-31 (bsc#1047581)
  - Added support for step-level preconditions
  - Added support for rate/interval based schedule expressions for
    associations
  - Added Summary and PackageID fields to inventory's
    aws:application gatherer
  - Changed inventory's aws:application gatherer to use
    win32_processor: addressWidth to detect OS architecture to
    avoid localization based errors
  - Fixed CloudWatch issue with large configuration
  - Fixed S3 upload when instance and bucket are not in the same
    region
  - Fixed bug that prevented native language AMIs (Japanese AMI)
    from launching Cloudwatch
  - Various bug fixes
- Update to 2.0.767.0 2017-05-31
  - Returning longer StandardOutput and StandardError from
    RunShellScript and RunPowerShellScript which show up in the
    results of GetCommandInvocation and the detailed output of
    ListCommandInvocation
  - Added Document v2.0 support for Run Command, which includes
    support for multiple actions of same plugin type
  - Various bug fixes
- Update to 2.0.755.0 2017-05-31
  - Fixed bugs that prevented CloudWatch from launching and allowed
    multiple instances of CloudWatch to launch on Windows
  - Various bug fixes
- Update to 2.0.730.0 2017-05-31
  - Fixed issues with agent starting before network is ready on
    systemd systems.
- Update to 2.0.716.0 2017-05-31
  - Pass proxy settings to domain join and CloudWatch
  - Added support for installing Docker on Linux
  - Removed the upper limit for the maximum number of parallel
    executing documents on the agent (previously the max was 10)
  - You can configure this number by setting the
    “CommandWorkerLimit” attribute in amazon-ssm-agent.json file
  - Various bug fixes
* Wed Mar  1 2017 lchiquitto@suse.de
- Add package to SLE-12 codestream (bsc#1017899, fate#322303)
* Fri Feb 17 2017 sean.marlow@suse.com
- Update to 2.0.672.0 2017-02-17
  - Added bucket-owner-full-control ACL to S3 outputs to support
    cross-account upload
  - Standardized S3 result paths across plugins; commands append
    command-id/instance-id/plugin-name/step-id associations append
    instance-id/association-id/execution-date/plugin-name/step-id
  - step-id is the id field in plugin input if present and
    supported, otherwise the step name (in 2.0 schema documents),
    otherwise the plugin-name again
  - plugin-name and step-id have : characters removed
  - FreeBSD patches from external contributor
  - Various bug fixes
* Thu Jan 19 2017 sean.marlow@suse.com
- Update to 2.0.663.0 2017-01-18
  - Added support for aws:softwareInventory plugin to upload
    inventory related log messages to S3
  - Added support for running Powershell on Linux
  - Added support for State Manager that automates the process of
    keeping your Amazon EC2 and hybrid infrastructure in a state that
    you define You can use State Manager to ensure that your instances
    are bootstrapped with specific software at startup, configured
    according to your security policy, joined to a Windows domain,
    or patched with specific software updates throughout their
    lifecycle
  - Added support for Systems Manager Inventory that allows you to
    specify the type of metadata to collect, the instances from
    where the metadata should be collected, and a schedule for
    metadata collection
  - Added support for installing, uninstalling, and updating AWS
    packages published by AWS
  - Added support for installing Docker on Windows and running
    Docker actions
  - Added support for Windows Server 2016
  - Added support for Windows Server Nano
  - Fixed CloudWatch crash issue
  - Fixed Domain Join to support customized OU
  - Fixed CloudWatch doesn't work with creating association from
    Console
  - Fixed SSM Agent not able to start on Windows Server 2003
  - Various bug fixes
* Fri Dec 16 2016 sean.marlow@suse.com
- Initial package 1.2.290.0 2016-07-20
